@@ -212,3 +212,93 @@ test_that("case_control_sampling_trials works with sort = TRUE", {
 
   expect_identical(samples_f, samples_t)
 })
+
+
+test_that("sample_controls works with trial_sequence objects containing te_datastore_datatable objects", {
+  trial_itt_dir <- file.path(tempdir(), "trial_itt")
+  dir.create(trial_itt_dir)
+
+  trial_itt <- trial_sequence(estimand = "ITT") |>
+    set_data(
+      data = data_censored,
+      id = "id",
+      period = "period",
+      treatment = "treatment",
+      outcome = "outcome",
+      eligible = "eligible"
+    ) |>
+    set_censor_weight_model(
+      censor_event = "censored",
+      numerator = ~ x1 + x2 + x3,
+      denominator = ~x2,
+      pool_models = "numerator",
+      model_fitter = stats_glm_logit(save_path = file.path(trial_itt_dir, "switch_models"))
+    ) |>
+    calculate_weights() |>
+    set_outcome_model(adjustment_terms = ~ x1 + x2)
+
+  trial_itt_datatable <- set_expansion_options(
+    trial_itt,
+    output = save_to_datatable(),
+    chunk_size = 500
+  ) |>
+    expand_trials()
+
+  # sample_controls works without additional arguments
+  sc_01 <- sample_controls(trial_itt_datatable, p_control = 0.01, seed = 1221)
+  expect_equal(
+    sort(sc_01@outcome_data@data$id),
+    c(
+      10, 14, 14, 15, 17, 21, 27, 29, 32, 38, 38, 44, 44, 49, 49,
+      54, 54, 54, 59, 61, 68, 71, 71, 71, 74, 74, 89, 98, 98, 99
+    )
+  )
+
+  random_01 <- sample_controls(trial_itt_datatable, p_control = 0.01)
+
+  # seed gets reset
+  sc_01_1 <- sample_controls(trial_itt_datatable, p_control = 0.01, seed = 1221)
+  random_02 <- sample_controls(trial_itt_datatable, p_control = 0.01)
+  expect_false(identical(sort(random_01@outcome_data@data$id), sort(random_02@outcome_data@data$id)))
+
+  # sample_controls works with p_control
+  sc_02 <- sample_controls(trial_itt_datatable, p_control = 0.5, seed = 5678)
+  expect_equal(sc_02@outcome_data@n_rows, 765)
+
+  # sample_controls works with p_control = 0
+  sc_03 <- sample_controls(trial_itt_datatable, p_control = 0)
+  expect_equal(sc_03@outcome_data@n_rows, 14)
+
+  # cases are kept
+  expect_equal(sum(sc_01@outcome_data@data$outcome), 14)
+  expect_equal(sum(sc_02@outcome_data@data$outcome), 14)
+  expect_equal(sum(sc_03@outcome_data@data$outcome), 14)
+
+  # all columns are kept and sample_weight column is added
+  expect_equal(
+    colnames(sc_01@outcome_data@data), c(colnames(trial_itt_datatable@expansion@datastore@data), "sample_weight")
+  )
+
+  # sample_controls subsets data correctly
+  sc_04 <- sample_controls(
+    trial_itt_datatable,
+    period = 1:10,
+    subset_condition = "followup_time <= 20 & treatment == 1",
+    p_control = 0.2,
+    seed = 2332
+  )
+  expect_equal(
+    sort(sc_04@outcome_data@data$id),
+    c(
+      14, 16, 20, 27, 27, 33, 33, 33, 33, 34, 34, 34, 44, 44, 44, 44, 44, 44, 44, 44, 47, 54, 54, 54, 54,
+      59, 59, 59, 59, 59, 59, 59, 60, 60, 60, 65, 71, 73, 74, 74, 74, 83, 95, 95, 95, 95, 95, 95, 95, 96
+    )
+  )
+
+  # sample_controls returns the correct classes
+  expect_class(sc_04, "trial_sequence_ITT")
+  expect_class(sc_04@outcome_data, "te_outcome_data")
+  expect_class(sc_04@outcome_data@data, "data.table")
+
+  unlink(trial_itt_dir, recursive = TRUE)
+})
